list/to_tuple.hpp

The list/to_tuple.hpp header defines macros to convert a list to a tuple.

#### Usage

#include <boost/preprocessor/list/to_tuple.hpp>

#### Contents

- BOOST_PP_LIST_TO_TUPLE
- BOOST_PP_LIST_TO_TUPLE_R

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)